@@ -5,8 +5,8 @@
 #' @param ... Any UI element.
 #' @param id To access the current state of the controlbar. Open is TRUE, closed
 #' is FALSE. NULL by default.
-#' @param disable If \code{TRUE}, the sidebar will be disabled.
-#' @param width Controlbar width. This must either be a number which specifies the width 
+#' @param disable If `TRUE`, the sidebar will be disabled.
+#' @param width Controlbar width. This must either be a number which specifies the width
 #' in pixels, or a string that specifies the width in CSS units. 250 px by default.
 #' @param collapsed Whether the control bar on the right side is collapsed or not at start. TRUE by default.
 #' @param overlay Whether the sidebar covers the content when expanded. Default to TRUE.
@@ -19,11 +19,20 @@
 #' @rdname dashboardControlbar
 #'
 #' @export
-bs4DashControlbar <- function(..., id = NULL, disable = FALSE, width = 250,
-                              collapsed = TRUE, overlay = TRUE, skin = NULL,
-                              pinned = NULL) {
-  if (is.null(id)) id <- "controlbarId"
-  
+bs4DashControlbar <- function(
+  ...,
+  id = NULL,
+  disable = FALSE,
+  width = 250,
+  collapsed = TRUE,
+  overlay = TRUE,
+  skin = NULL,
+  pinned = NULL
+) {
+  if (is.null(id)) {
+    id <- "controlbarId"
+  }
+
   skin <- set_sidebar_skin(skin)
 
   controlbarTag <- shiny::tags$aside(
@@ -57,24 +66,32 @@ bs4DashControlbar <- function(..., id = NULL, disable = FALSE, width = 250,
           shiny::HTML(
             paste0(
               ".control-sidebar, .control-sidebar:before {
-                width: ", shiny::validateCssUnit(width), ";
-                right: -", shiny::validateCssUnit(width), ";
+                width: ",
+              shiny::validateCssUnit(width),
+              ";
+                right: -",
+              shiny::validateCssUnit(width),
+              ";
                 bottom: 0;
                 transition: right 0.3s ease-in-out;
               }
-              .control-sidebar-slide-open.control-sidebar-push .content-wrapper, 
-              .control-sidebar-slide-open.control-sidebar-push .main-footer, 
-              .control-sidebar-slide-open.control-sidebar-push-slide .content-wrapper, 
+              .control-sidebar-slide-open.control-sidebar-push .content-wrapper,
+              .control-sidebar-slide-open.control-sidebar-push .main-footer,
+              .control-sidebar-slide-open.control-sidebar-push-slide .content-wrapper,
               .control-sidebar-slide-open.control-sidebar-push-slide .main-footer {
-                margin-right: ", shiny::validateCssUnit(width), ";
+                margin-right: ",
+              shiny::validateCssUnit(width),
+              ";
               }
 
               @media (min-width: 768px)
-                body:not(.sidebar-mini-md) .content-wrapper, 
-                body:not(.sidebar-mini-md) .main-footer, 
+                body:not(.sidebar-mini-md) .content-wrapper,
+                body:not(.sidebar-mini-md) .main-footer,
                 body:not(.sidebar-mini-md) .main-header {
                   transition: margin-left .3s ease-in-out;
-                  margin-left: ", shiny::validateCssUnit(width), ";
+                  margin-left: ",
+              shiny::validateCssUnit(width),
+              ";
                 }
               "
             )
@@ -87,16 +104,12 @@ bs4DashControlbar <- function(..., id = NULL, disable = FALSE, width = 250,
 }
 
 
-
-
 #' @inheritParams tabsetPanel
 #' @rdname dashboardControlbar
 #' @export
 controlbarMenu <- tabsetPanel
 
 
-
-
 #' @inheritParams shiny::tabPanel
 #' @rdname dashboardControlbar
 #' @export
@@ -105,17 +118,16 @@ controlbarItem <- function(title, ..., value = title, icon = NULL) {
 }
 
 
-
-
 #' @inheritParams shiny::updateTabsetPanel
 #' @rdname dashboardControlbar
 #' @export
-updateControlbarMenu <- function (session = shiny::getDefaultReactiveDomain(), inputId, selected = NULL) {
+updateControlbarMenu <- function(
+  session = shiny::getDefaultReactiveDomain(),
+  inputId,
+  selected = NULL
+) {
   shiny::updateTabsetPanel(session = session, inputId, selected = selected)
 }
-  
-
-
 
 
 #' Function to programmatically toggle the state of the controlbar
