@@ -68,14 +68,12 @@ renderbs4ValueBox <- function(expr, env = parent.frame(), quoted = FALSE) {
 }
 
 
-
 #' @rdname infoBox
 #' @inheritParams renderbs4ValueBox
 #' @export
 renderbs4InfoBox <- renderbs4ValueBox
 
 
-
 #' Create a value box output (client side)
 #'
 #' This is the UI-side function for creating a dynamic \code{\link{bs4ValueBox}}.
@@ -91,16 +89,12 @@ bs4ValueBoxOutput <- function(outputId, width = 4) {
 }
 
 
-
 #' @rdname infoBox
 #' @inheritParams bs4ValueBoxOutput
 #' @export
 bs4InfoBoxOutput <- bs4ValueBoxOutput
 
 
-
-
-
 #' Create a dynamic menu output for bs4Dash (client side)
 #'
 #' This can be used as a placeholder for dynamically-generated
@@ -112,7 +106,7 @@ bs4InfoBoxOutput <- bs4ValueBoxOutput
 #' \code{\link{sidebarMenuOutput}}.
 #'
 #' @param outputId Output variable name.
-#' @param tag A tag function, like \code{tags$li} or \code{tags$ul}.
+#' @param tag A tag function, like `tags$li` or `tags$ul`.
 #'
 #' @family menu outputs
 #' @seealso \code{\link{renderMenu}} for the corresponding server side function
@@ -122,8 +116,6 @@ menuOutput <- function(outputId, tag = shiny::tags$li) {
 }
 
 
-
-
 #' Create a dropdown menu output (client side)
 #'
 #' This is the UI-side function for creating a dynamic dropdown menu.
@@ -139,8 +131,6 @@ dropdownMenuOutput <- function(outputId) {
 }
 
 
-
-
 #' Create a sidebar menu output (client side)
 #'
 #' This is the UI-side function for creating a dynamic sidebar menu.
@@ -156,9 +146,6 @@ sidebarMenuOutput <- function(outputId) {
 }
 
 
-
-
-
 #' Create a sidebar menu item output (client side)
 #'
 #' This is the UI-side function for creating a dynamic sidebar menu item.
@@ -174,8 +161,6 @@ menuItemOutput <- function(outputId) {
 }
 
 
-
-
 #' Create dynamic menu output (server side)
 #'
 #' @inheritParams shiny::renderUI
@@ -255,15 +240,15 @@ menuItemOutput <- function(outputId) {
 #'
 #'   shinyApp(ui, server)
 #' }
-renderMenu <- function(expr, env = parent.frame(), quoted = FALSE, outputArgs = list()) {
+renderMenu <- function(
+  expr,
+  env = parent.frame(),
+  quoted = FALSE,
+  outputArgs = list()
+) {
   if (!quoted) {
     expr <- substitute(expr)
     quoted <- TRUE
   }
   shiny::renderUI(expr, env = env, quoted = quoted, outputArgs = outputArgs)
 }
-
-  
-  
-
-
