@@ -18,14 +18,14 @@ shinyApp(
     header = dashboardHeader(),
     sidebar = dashboardSidebar(
       width = "100px",
-      minified = TRUE, 
+      minified = TRUE,
       collapsed = TRUE,
       sidebarMenu(
         id = "sidebarMenu",
         lapply(1:3, function(i) {
           menuItem(
-            sprintf("Menu %s", i), 
-            tabName = sprintf("menu_%s", i), 
+            sprintf("Menu %s", i),
+            tabName = sprintf("menu_%s", i),
             icon = icon("circle")
           )
         })
@@ -33,22 +33,22 @@ shinyApp(
     ),
     body = dashboardBody(
       tabItems(
-        tabItem(tabName = "menu_1", "Content 1"), 
+        tabItem(tabName = "menu_1", "Content 1"),
         tabItem(
           tabName = "menu_2",
           box(
             title = "Always the same plot!",
-            collapsible = TRUE, 
+            collapsible = TRUE,
             width = 6,
             plotOutput("distPlot"),
             sidebar = boxSidebar(
               id = "boxSidebar",
               background = "#808080",
               sliderInput(
-                "obs", 
+                "obs",
                 "Number of observations:",
                 min = 0,
-                max = 1000, 
+                max = 1000,
                 value = 500
               )
             )
@@ -73,17 +73,24 @@ shinyApp(
       if (idx == 2) {
         updateControlbar("controlbar")
       }
-      updateControlbarMenu(session = session, "controlbarMenu", selected = paste("Tab", idx))
+      updateControlbarMenu(
+        session = session,
+        "controlbarMenu",
+        selected = paste("Tab", idx)
+      )
     })
-    
+
     # Clicking on the second controlbar item makes the box sidebar open
     observeEvent(input$controlbarMenu, {
       if (input$controlbarMenu == "Tab 2") updateBoxSidebar("boxSidebar")
     })
-    
-    observeEvent(input$num, {
-      updateSliderInput(session, "obs", value = input$num)
-    }, ignoreInit = TRUE)
-    
+
+    observeEvent(
+      input$num,
+      {
+        updateSliderInput(session, "obs", value = input$num)
+      },
+      ignoreInit = TRUE
+    )
   }
 )
